<?php

namespace EventPortal\Tests\Support\Traits;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Venue\Models\Venue;
use Illuminate\Support\Arr;

trait InteractsWithEventVenues
{
    public function assertEventHasVenue(Event $event, Venue $venue): self
    {
        $this->assertDatabaseHas('event_venue', [
            'venue_id' => $venue->id,
            'event_id' => $event->id,
        ]);

        return $this;
    }

    /**
     * @param Venue|array<Venue> $speakers
     */
    public function assertEventHasVenues(Event $event, $venues): self
    {
        foreach (Arr::wrap($venues) as $venue) {
            $this->assertEventHasVenue($event, $venue);
        }

        return $this;
    }

    public function assertEventMissingVenue(Event $event, Venue $venue): self
    {
        $this->assertDatabaseMissing('event_venue', [
            'venue_id' => $venue->id,
            'event_id' => $event->id,
        ]);

        return $this;
    }

    /**
     * @param Venue|array<Venue> $speaker
     */
    public function assertEventMissingVenues(Event $event, $venues): self
    {
        foreach (Arr::wrap($venues) as $venue) {
            $this->assertEventMissingVenue($event, $venue);
        }

        return $this;
    }
}
